@@ -76,14 +76,18 @@ def print_version_info() -> None:
         "locale": locale.getpreferredencoding(),
     }
 
-    from pip._internal.utils.misc import get_installed_distributions
-    installed = get_installed_distributions()
-    pkgs = {_.project_name: _.version for _ in installed}
-    for pkg_name, pkg_version in pkgs.items():
-        include = ('duckietown' in pkg_name) or ('dt-' in pkg_name) or ('-z' in pkg_name) or (
-                'aido' in pkg_name)
-        if include:
-            v[pkg_name] = pkg_version
+    try:
+        from pip._internal.utils.misc import get_installed_distributions
+    except ImportError:
+        dtslogger.warning('Please update "pip" to have better debug info.')
+    else:
+        installed = get_installed_distributions()
+        pkgs = {_.project_name: _.version for _ in installed}
+        for pkg_name, pkg_version in pkgs.items():
+            include = ('duckietown' in pkg_name) or ('dt-' in pkg_name) or ('-z' in pkg_name) or (
+                    'aido' in pkg_name)
+            if include:
+                v[pkg_name] = pkg_version
 
     versions = yaml.dump(v, default_flow_style=False)
     # Please = termcolor.colored('Please', 'red', attrs=['bold'])
